@@ -1,6 +1,5 @@
-from invoke import Collection, Program, Task
-
 import pkg_resources
+from invoke import Collection, Program, Task
 
 from . import core, db, shorthands
 
@@ -10,10 +9,7 @@ namespace = Collection()
 
 # Load up some of our functions into the root namespace.
 for core_ns in [core, shorthands]:
-    tasks = filter(
-        lambda x: isinstance(x, Task),
-        vars(core_ns).values()
-    )
+    tasks = filter(lambda x: isinstance(x, Task), vars(core_ns).values())
     for task in tasks:
         namespace.add_task(task)
 
